.. highlight:: shell

============
Installation
============


Stable release
--------------

To install seshypy, run this command in your terminal:

.. code-block:: console

    $ pip install seshypy

This is the preferred method to install, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for howsitgoing can be downloaded from the `Github repo`_.

Clone the repository:

.. code-block:: console

    $ git clone git@github.com:cleardataeng/seshypy.git

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/cleardataeng/seshypy
